==> digikam_8.2.0.orig.tar.xz: digikam-8.2.0/core/dplugins/generic/tools/htmlgallery/generator/galleryelementfunctor.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2006-04-04
 * Description : a tool to generate HTML image galleries
 *
 * SPDX-FileCopyrightText: 2006-2010 by Aurelien Gateau <aurelien dot gateau at free dot fr>
 * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#ifndef DIGIKAM_GALLERY_ELEMENT_FUNCTOR_H
#define DIGIKAM_GALLERY_ELEMENT_FUNCTOR_H

// Local includes

#include "gallerynamehelper.h"

namespace DigikamGenericHtmlGalleryPlugin
{

class GalleryInfo;
class GalleryGenerator;
class GalleryElement;

/**
 * This functor generates images (full and thumbnail) for an url and returns an
 * GalleryElement initialized to fill the xml writer.
 * It is used as an argument to QtConcurrent::mapped().
 */
class GalleryElementFunctor
{
public:

    typedef GalleryElement result_type;

public:

    explicit GalleryElementFunctor(GalleryGenerator* const generator,
                                   GalleryInfo* const info,
                                   const QString& destDir);
    ~GalleryElementFunctor();

    void operator()(GalleryElement& element);

private:

    bool writeDataToFile(const QByteArray& data, const QString& destPath);
    void emitWarning(const QString& msg);

private:

    // NOTE: Do not use a d private internal container here.

    GalleryGenerator* m_generator;
    GalleryInfo*      m_info;
    QString           m_destDir;
    GalleryNameHelper m_uniqueNameHelper;
};

} // namespace DigikamGenericHtmlGalleryPlugin

#endif // DIGIKAM_GALLERY_ELEMENT_FUNCTOR_H

==> digikam_8.8.0.orig.tar.xz: digikam-8.8.0/core/dplugins/generic/tools/htmlgallery/generator/galleryelementfunctor.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2006-04-04
 * Description : a tool to generate HTML image galleries
 *
 * SPDX-FileCopyrightText: 2006-2010 by Aurelien Gateau <aurelien dot gateau at free dot fr>
 * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#pragma once

// Qt includes

#include <QImage>

// Local includes

#include "gallerynamehelper.h"

namespace DigikamGenericHtmlGalleryPlugin
{

class GalleryInfo;
class GalleryGenerator;
class GalleryElement;

/**
 * This functor generates images (full and thumbnail) for an url and returns an
 * GalleryElement initialized to fill the xml writer.
 * It is used as an argument to QtConcurrent::mapped().
 */
class GalleryElementFunctor
{
public:

    typedef GalleryElement result_type;

public:

    explicit GalleryElementFunctor(GalleryGenerator* const generator,
                                   GalleryInfo* const info,
                                   const QString& destDir);
    ~GalleryElementFunctor() = default;

    void operator()(GalleryElement& element);

private:

    void   emitWarning(const QString& msg);
    QImage generateThumbnail(const QImage& fullImage, int size, bool square) const;

private:

    // NOTE: Do not use a d private internal container here.

    GalleryGenerator* m_generator = nullptr;
    GalleryInfo*      m_info      = nullptr;
    QString           m_destDir;
    GalleryNameHelper m_uniqueNameHelper;
};

} // namespace DigikamGenericHtmlGalleryPlugin
